@@ -12,10 +12,12 @@ from making_with_code_cli.styles import (
     address,
     question,
     info,
+    debug,
     confirm,
     error,
 )
 from making_with_code_cli.settings import (
+    get_settings_path,
     read_settings, 
     iter_settings,
     write_settings,
@@ -65,10 +67,15 @@ def version():
 @click.option("--yes", is_flag=True, help="Automatically answer 'yes' to setup prompts")
 @click.option("--teacher", is_flag=True, help="Install in teacher mode")
 @click.option("--config", help="Path to config file (default: ~/.mwc)")
+@click.option("--debug", is_flag=True, help="Show debug-level output")
 @click.pass_context
-def setup(ctx, yes, teacher, config):
+def setup(ctx, yes, teacher, config, debug):
     """Set up the MWC command line interface"""
     settings = read_settings(config)
+    if debug:
+        click.echo(debug(f"Reading settings from {get_settings_path(config)}"))
+        for k, v in settings.items():
+            click.echo(debug(f" - {k}: {v}"))
     rc_tasks = []
     click.echo(address(INTRO_MESSAGE))
     for note in INTRO_NOTES:
@@ -114,9 +121,18 @@ def setup(ctx, yes, teacher, config):
         GHAuthentication(settings),
         GitConfiguration(settings),
     ]
+    errors = []
     for task in tasks:
-        task.run_task_if_needed()
-    
+        try:
+            task.run_task_if_needed()
+        except Exception as e:
+            errors.append((task, traceback.format_exc()))
+    if errors:
+        click.echo(error(f"{len(errors)} setup tasks failed:"))
+        for task, tb in errors:
+            click.echo(error(task.descrition))
+            if debug:
+                click.echo(debug(tb, preformatted=True))
     ctx.invoke(update)
 
 def get_course_by_name(name, courses):
