@@ -2,24 +2,27 @@ from pathlib import Path
 import yaml
 import os
 
-# The default location for the MWC configuration file is ~/.mwc.
-# This can be specified (e.g. to support parallel installations) using
-# the MWC_CONFIG environment variable or the --config flag.
+
+def get_settings_path(settings_path=None):
+    """Determines the settings path, based on what is passed and environment.
+    "The default location for the MWC configuration file is ~/.mwc.
+    This can be specified (e.g. to support parallel installations) using
+    the MWC_CONFIG environment variable or the --config flag.
+    """
+    if settings_path:
+        return = Path(settings_path)
+    elif "MWC_CONFIG" in os.environ:
+        return Path(os.environ["MWC_CONFIG"])
+    else:
+        return Path.home() / ".mwc"
 
 def read_settings(settings_path=None):
     """Reads the settings file and returns a dict. 
     If the settings file does not exist, returns {}
     """
-    if settings_path:
-        settings_path = Path(settings_path)
-    else:
-        if "MWC_CONFIG" in os.environ:
-            settings_path = Path(os.environ["MWC_CONFIG"])
-        else:
-            settings_path = Path.home() / ".mwc"
-
-    if settings_path.exists():
-        return yaml.safe_load(settings_path.read_text())
+    sp = get_settings_path(settings_path)
+    if sp.exists():
+        return yaml.safe_load(sp.read_text())
     else:
         return {}
 
